@@ -1,7 +1,7 @@
 package Test::Some;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: test a subset of tests
-$Test::Some::VERSION = '0.0.3';
+$Test::Some::VERSION = '0.1.0';
 
 use 5.10.0;
 
@@ -20,18 +20,28 @@ sub import {
     my $caller = caller;
     my(undef,@filters) = @_;
 
+    no warnings 'uninitialized';
+    @filters = split ',', $ENV{TEST_SOME} unless @filters;
+
     _groom_filter($caller,$_) for @filters;
 
-    state $first_time = 1;
-
-    eval <<"END" if $first_time;
-        package 
-            Test::More;
+    eval <<"END_EVAL";
+        package $caller; 
+        use Test::More;
         use Class::Method::Modifiers;
-        around subtest => sub { Test::Some::_subtest( \@_ ) };
-END
 
-    $first_time = 0;
+        # needs to be after Test::More put
+        # its own 'subtest' in there,
+        # hence the INIT
+        INIT {
+            around subtest => sub {
+                Test::Some::_subtest(\@_);
+            }
+        }
+END_EVAL
+
+    die $@ if $@;
+
 }
 
 sub _groom_filter { 
@@ -113,7 +123,7 @@ Test::Some - test a subset of tests
 
 =head1 VERSION
 
-version 0.0.3
+version 0.1.0
 
 =head1 SYNOPSIS
 
@@ -136,10 +146,17 @@ The module declaration takes a whitelist of the subtests we want to run.
 Any subtest that doesn't match any of the whitelist
 items will be skipped (or potentially bypassed).
 
-The test files don't even need to be modified, as t
-he module can also be invoked from the command-line. E.g.,
+The test files don't even need to be modified, as 
+the module can also be invoked from the command-line. E.g.,
 
-    perl -MTest::Some=foo t/tests.t
+    $ perl -MTest::Some=foo t/tests.t
+
+If no argument is given to the module declaration, the environment
+variable C<TEST_SOME> will be used as the defaults. For example, this 
+is equivalent to the example above:
+
+    $ export TEST_SOME=foo
+    $ perl -MTest::Some t/tests.t
 
 =head2 Whitelist items
 
